@@ -10,7 +10,7 @@ describe Object do
     end
 
     if mongoid?
-      it 'should return class with namesapce and id composition' do
+      it 'should return class with namespace and id composition' do
         post = Mongoid::Post.first
         expect(post.bullet_key).to eq("Mongoid::Post:#{post.id}")
       end
@@ -30,12 +30,18 @@ describe Object do
       Post.primary_key = 'id'
     end
 
-    it 'should return value for multiple primary keys' do
+    it 'should return value for multiple primary keys from the composite_primary_key gem' do
       post = Post.first
       allow(Post).to receive(:primary_keys).and_return(%i[category_id writer_id])
       expect(post.bullet_primary_key_value).to eq("#{post.category_id},#{post.writer_id}")
     end
 
+    it 'should return value for multiple primary keys from ActiveRecord 7.1' do
+      post = Post.first
+      allow(Post).to receive(:primary_key).and_return(%i[category_id writer_id])
+      expect(post.bullet_primary_key_value).to eq("#{post.category_id},#{post.writer_id}")
+    end
+
     it 'it should return nil for unpersisted records' do
       post = Post.new(id: 123)
       expect(post.bullet_primary_key_value).to be_nil
