@@ -1,3 +1,4 @@
 # frozen_string_literal: true
 
-class Writer < BaseUser; end
+class Writer < BaseUser
+end
